@@ -8,6 +8,7 @@ from . import DATA_DIR
 DATA_DIR = os.path.join(DATA_DIR,"ytd")
 settingsfile = os.path.join(DATA_DIR,"presets.yml")
 configfiles = ["ytd.yml","ytd.yaml",".ytd"]
+processname = "yt-dlp"
 
 @mainfunction({},shield=True)
 def main(preset=None,url=None,new=None):
@@ -37,8 +38,9 @@ def main(preset=None,url=None,new=None):
 			flags = selected.get("flags",[])
 
 
-		print("Downloading to directory",folder)
+		print("[ytd] Downloading to directory",folder)
 		tmpfolder = folder
+		print("[ytd] Reading local settings...")
 		while True:
 			for c in configfiles:
 				local_configfile = os.path.join(tmpfolder,c)
@@ -47,7 +49,7 @@ def main(preset=None,url=None,new=None):
 						localsettings = yaml.safe_load(f)
 						if "options" in localsettings: options.update(localsettings["options"])
 						if "flags" in localsettings: flags += localsettings["flags"]
-						print("Reading settings from",local_configfile)
+						print("[ytd]\t",local_configfile)
 				except:
 					pass
 
@@ -64,7 +66,7 @@ def main(preset=None,url=None,new=None):
 		cmd_options = ["--" + k + " " + options[k] for k in options]
 		cmd_flags = ["--" + k for k in flags]
 
-		cmd = "youtube-dl " + " ".join(cmd_options) + " " + " ".join(cmd_flags) + " " + url
+		cmd = "[ytd] Issuing command: " + processname + " " + " ".join(cmd_options) + " " + " ".join(cmd_flags) + " " + url
 		print(cmd)
 		os.system(cmd)
 
